==> developer-center-api-3.6.20.6-20210730.035007-5-sources.jar: cn/com/duiba/developer/center/api/domain/dto/url/AppLabelDetailDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.url;

import java.io.Serializable;
import java.util.Date;

/**
 * @program: developer-center
 * @description:
 * @author: fenghuohuo
 * @create: 2021-07-28 16:34
 **/
public class AppLabelDetailDto implements Serializable {
    private static final long serialVersionUID = 545592839380017046L;

    private Long id;

    /**
     * appId
     */
    private Long appId;

    /**
     * app名称
     */
    private String appName;

    /**
     * 标签名称
     */
    private String labelName;

    /**
     * 具体域名
     */
    private String fullDomain;

    /**
     * 泛域名
     */
    private String domain;

    /**
     * 状态
     * @see cn.com.duiba.developer.center.api.domain.enums.newDomain.AppLabelDetailStatusEnum
     */
    private Integer status;

    /**
     * 域名前缀
     */
    private String prefix;

    public Long getId() {
        return id;
    }

    public AppLabelDetailDto setId(Long id) {
        this.id = id;
        return this;
    }

    public Long getAppId() {
        return appId;
    }

    public AppLabelDetailDto setAppId(Long appId) {
        this.appId = appId;
        return this;
    }

    public String getAppName() {
        return appName;
    }

    public AppLabelDetailDto setAppName(String appName) {
        this.appName = appName;
        return this;
    }

    public String getLabelName() {
        return labelName;
    }

    public AppLabelDetailDto setLabelName(String labelName) {
        this.labelName = labelName;
        return this;
    }

    public String getFullDomain() {
        return fullDomain;
    }

    public AppLabelDetailDto setFullDomain(String fullDomain) {
        this.fullDomain = fullDomain;
        return this;
    }

    public String getDomain() {
        return domain;
    }

    public AppLabelDetailDto setDomain(String domain) {
        this.domain = domain;
        return this;
    }

    public Integer getStatus() {
        return status;
    }

    public AppLabelDetailDto setStatus(Integer status) {
        this.status = status;
        return this;
    }

    public String getPrefix() {
        return prefix;
    }

    public AppLabelDetailDto setPrefix(String prefix) {
        this.prefix = prefix;
        return this;
    }
}

==> developer-center-api-3.11.5-sources.jar: cn/com/duiba/developer/center/api/domain/dto/url/AppLabelDetailDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.url;

import java.io.Serializable;
import java.util.Date;

/**
 * @program: developer-center
 * @description:
 * @author: fenghuohuo
 * @create: 2021-07-28 16:34
 **/
public class AppLabelDetailDto implements Serializable {
    private static final long serialVersionUID = 545592839380017046L;

    private Long id;

    /**
     * appId
     */
    private Long appId;

    /**
     * app名称
     */
    private String appName;

    /**
     * 标签id
     */
    private Long labelId;

    /**
     * 标签名称
     */
    private String labelName;

    /**
     * 具体域名
     */
    private String fullDomain;

    /**
     * 泛域名
     */
    private String domain;

    /**
     * 状态
     * @see cn.com.duiba.developer.center.api.domain.enums.newDomain.AppLabelDetailStatusEnum
     */
    private Integer status;

    /**
     * 域名前缀
     */
    private String prefix;

    public Long getId() {
        return id;
    }

    public AppLabelDetailDto setId(Long id) {
        this.id = id;
        return this;
    }

    public Long getAppId() {
        return appId;
    }

    public AppLabelDetailDto setAppId(Long appId) {
        this.appId = appId;
        return this;
    }

    public String getAppName() {
        return appName;
    }

    public AppLabelDetailDto setAppName(String appName) {
        this.appName = appName;
        return this;
    }

    public String getLabelName() {
        return labelName;
    }

    public AppLabelDetailDto setLabelName(String labelName) {
        this.labelName = labelName;
        return this;
    }

    public String getFullDomain() {
        return fullDomain;
    }

    public AppLabelDetailDto setFullDomain(String fullDomain) {
        this.fullDomain = fullDomain;
        return this;
    }

    public String getDomain() {
        return domain;
    }

    public AppLabelDetailDto setDomain(String domain) {
        this.domain = domain;
        return this;
    }

    public Integer getStatus() {
        return status;
    }

    public AppLabelDetailDto setStatus(Integer status) {
        this.status = status;
        return this;
    }

    public String getPrefix() {
        return prefix;
    }

    public AppLabelDetailDto setPrefix(String prefix) {
        this.prefix = prefix;
        return this;
    }

    public Long getLabelId() {
        return labelId;
    }

    public AppLabelDetailDto setLabelId(Long labelId) {
        this.labelId = labelId;
        return this;
    }
}
